==> ejc-jltest-api-3.0.0-20240310.070756-42-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangerdDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细D
 * 
 * @author generator
 * 
 */
public class DangerdDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerdId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Integer detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfCheck; // 自查情况
    private String judgmentResult; // 判定结果
    private String memo; // 备注
    

    public Long getDangerdId() {
        return dangerdId;
    }

    public void setDangerdId(Long dangerdId) {
        this.dangerdId = dangerdId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public Integer getDetailCategory() {
        return detailCategory;
    }

    public void setDetailCategory(Integer detailCategory) {
        this.detailCategory = detailCategory;
    }
    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfCheck() {
        return selfCheck;
    }

    public void setSelfCheck(String selfCheck) {
        this.selfCheck = selfCheck;
    }
    public String getJudgmentResult() {
        return judgmentResult;
    }

    public void setJudgmentResult(String judgmentResult) {
        this.judgmentResult = judgmentResult;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jltest-api-3.0.0-20251024.061248-161-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangerdDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细D
 * 
 * @author generator
 * 
 */
public class DangerdDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerdId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfCheck; // 自查情况
    private String judgmentResult; // 判定结果
    private String memo; // 备注
    

    public Long getDangerdId() {
        return dangerdId;
    }

    public void setDangerdId(Long dangerdId) {
        this.dangerdId = dangerdId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDetailCategory() {
        return detailCategory;
    }

    @ReferDeserialTransfer
    public void setDetailCategory(Long detailCategory) {
        this.detailCategory = detailCategory;
    }
    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfCheck() {
        return selfCheck;
    }

    public void setSelfCheck(String selfCheck) {
        this.selfCheck = selfCheck;
    }
    public String getJudgmentResult() {
        return judgmentResult;
    }

    public void setJudgmentResult(String judgmentResult) {
        this.judgmentResult = judgmentResult;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
